%% Electron Backscatter Diffraction Data (The Class [[EBSD_index.html,EBSD]])
% This section describes the class *EBSD* and gives an overview over the
% functionality that MTEX offers to analyze EBSD data.
%
%% Contents
%
%% Class Description 
% 
% The following mindmap might give a basic idea about EBSD data
% analyis in MTEX, with the ability of <GrainReconstruction.html grain
% modelling> for spatial data. It offers various way of interpreting
% individual orientation measurements, i.e. in terms of quantifying
% macro-,micro- and  mesotexture.
%
% <<grain.png>>
%
%% SUB: Import of EBSD Data
%
% The most comfortable way to import EBSD data into MTEX is to use
% the import wizard, which can be started by the command
%
import_wizard('ebsd')

%%
% If the dataset is in a format supported by MTEX, the import wizard generates
% a script which imports the data. More information about the import wizard
% and a list of supported file formats can be found
% <ImportEBSDData.html,here>. A typical script generated by the import 
% wizard looks a follows.


cs = crystalSymmetry('m-3m','mineral','Fe');      % crystal symmetry

% file names
fname = fullfile(mtexDataPath,'EBSD','85_829grad_07_09_06.txt');

% load data
ebsd = loadEBSD(fname,'CS',cs,... 
                'interface','generic','Bunge','ignorePhase',[0 2],...
                 'ColumnNames', { 'Phase' 'x' 'y' 'Euler 1' 'Euler 2' 'Euler 3'},...
                 'Columns', [2 3 4 5 6 7])

%% SUB: Plotting EBSD Data
%
% EBSD data are plotted using the command <EBSD.plot.html,plot>.
% It assigns a color to each orientation and plots a map of these colors.
% There are several options to specify the way the colors are assigned.

oM = ipdfHSVOrientationMapping(ebsd);
plot(ebsd,oM.orientation2color(ebsd.orientations))

%%
% In order to understand the color coding, one can plot the coloring of the
% corresponding inverse pole figure via

plot(oM)
hold on
plotIPDF(ebsd('Fe').orientations,xvector,'markerSize',3,'points',500,'marker','o','markerfacecolor','none','markeredgecolor','k')
hold off

%% SUB: Modify EBSD Data
%
% MTEX offers a lot of operations to analyze and manipulate EBSD data, e.g.
%
% * plot pole figures of EBSD data
% * rotate EBSD data
% * find outliers
% * remove specific measurements
% * combine EBSD data from several measurements
% * compute an ODF
%
% An exhaustive introduction how to analyze and modify EBSD data can be found
% <EBSDModifyData.html here>

%% SUB: Calculate an ODF from EBSD Data
%
% The command <EBSD.calcODF.html calcODF>  performs an ODF calculation
% from EBSD data using kernel density estimation EBSD data. For a precise
% explanation of the algorithm and the available options please look at
% <EBSD2odf.html here>. 

odf = calcODF(ebsd('Fe').orientations,'halfwidth',10*degree)
plotPDF(odf,Miller(1,0,0,odf.CS),'antipodal')


%% SUB: Simulate EBSD Data
%
% Simulating EBSD data from a given ODF is useful to analyze the stability of the 
% ODF estimation process. There is an <EBSDSimulation_demo.html example> demonstrating 
% how to determine the number of individual orientation measurements to estimate the 
% ODF up to a given error. The MTEX command to simulate EBSD data is
% <ODF.calcEBSD.html calcEBSD>, e.g.

ori = calcOrientations(unimodalODF(orientation(idquaternion,cs)),500)
plotPDF(ori,Miller(1,0,0,cs),'antipodal','MarkerSize',3)

%% SUB: Demo
%
% For a more exhaustive description of the EBSD class have a look at the 
% <ebsd_demo.html EBSD demo>!
% 

%% Complete Function list
% 
% <html><table width="90%"><tr><td width="200px"><a href="EBSD.EBSD.html"><tt>EBSD</tt></a></td><td>constructor</td></tr><tr><td width="200px"><a href="EBSD.KAM.html"><tt>KAM</tt></a></td><td>intragranular average misorientation angle per orientation</td></tr><tr><td width="200px"><a href="EBSD.affinetrans.html"><tt>affinetrans</tt></a></td><td>perform an affine transformation on spatial ebsd data</td></tr><tr><td width="200px"><a href="EBSD.calcGrains.html"><tt>calcGrains</tt></a></td><td>grains reconstruction from 2d EBSD data</td></tr><tr><td width="200px"><a href="EBSD.calcMisorientation.html"><tt>calcMisorientation</tt></a></td><td>calculate uncorrelated misorientations between two ebsd phases</td></tr><tr><td width="200px"><a href="EBSD.calcTensor.html"><tt>calcTensor</tt></a></td><td>compute the average tensor for an EBSD data set</td></tr><tr><td width="200px"><a href="EBSD.cat.html"><tt>cat</tt></a></td><td>overloads [ebsd1,ebsd2,ebsd3..]</td></tr><tr><td width="200px"><a href="EBSD.char.html"><tt>char</tt></a></td><td>ebsd &gt; char</td></tr><tr><td width="200px"><a href="EBSD.display.html"><tt>display</tt></a></td><td>standard output</td></tr><tr><td width="200px"><a href="EBSD.export.html"><tt>export</tt></a></td><td>EBSD data to a ascii file</td></tr><tr><td width="200px"><a href="EBSD.export_h5.html"><tt>export_h5</tt></a></td><td>export EBSD data to a ascii file</td></tr><tr><td width="200px"><a href="EBSD.extend.html"><tt>extend</tt></a></td><td>returns the boundings of spatial EBSD data</td></tr><tr><td width="200px"><a href="EBSD.fill.html"><tt>fill</tt></a></td><td>extrapolate spatial EBSD data by nearest neighbour for tetragonal lattice</td></tr><tr><td width="200px"><a href="EBSD.fillByGrainId.html"><tt>fillByGrainId</tt></a></td><td>extrapolate spatial EBSD data by nearest neighbour for tetragonal lattice</td></tr><tr><td width="200px"><a href="EBSD.findByLocation.html"><tt>findByLocation</tt></a></td><td>select EBSD data by spatial coordinates</td></tr><tr><td width="200px"><a href="EBSD.findByOrientation.html"><tt>findByOrientation</tt></a></td><td>select ebsd data by orientation</td></tr><tr><td width="200px"><a href="EBSD.fliplr.html"><tt>fliplr</tt></a></td><td>flip spatial ebsddata from left to right</td></tr><tr><td width="200px"><a href="EBSD.flipud.html"><tt>flipud</tt></a></td><td>flip spatial ebsddata from upside down</td></tr><tr><td width="200px"><a href="EBSD.gridify.html"><tt>gridify</tt></a></td><td>extend EBSD data to an grid</td></tr><tr><td width="200px"><a href="EBSD.id2ind.html"><tt>id2ind</tt></a></td><td>find ind such that ebsd.id(ind) == id</td></tr><tr><td width="200px"><a href="EBSD.inpolygon.html"><tt>inpolygon</tt></a></td><td>checks which ebsd data are within given polygon</td></tr><tr><td width="200px"><a href="EBSD.mtimes.html"><tt>mtimes</tt></a></td><td>rotating the ebsd data by a certain rotation </td></tr><tr><td width="200px"><a href="EBSD.plot.html"><tt>plot</tt></a></td><td>spatial EBSD plot</td></tr><tr><td width="200px"><a href="EBSD.quiver.html"><tt>quiver</tt></a></td><td>plot directions at ebsd centers</td></tr><tr><td width="200px"><a href="EBSD.reduce.html"><tt>reduce</tt></a></td><td>ebsd data by a factor</td></tr><tr><td width="200px"><a href="EBSD.rotate.html"><tt>rotate</tt></a></td><td>EBSD orientations or spatial data around point of origin</td></tr><tr><td width="200px"><a href="EBSD.shift.html"><tt>shift</tt></a></td><td>spatial ebsddata about (x,y)</td></tr><tr><td width="200px"><a href="EBSD.smooth.html"><tt>smooth</tt></a></td><td>spatial EBSD </td></tr><tr><td width="200px"><a href="EBSD.spatialProfile.html"><tt>spatialProfile</tt></a></td><td>select EBSD data along line segments</td></tr><tr><td width="200px"><a href="EBSD.subSet.html"><tt>subSet</tt></a></td><td>indexing of EBSD data</td></tr><tr><td width="200px"><a href="EBSD.subsasgn.html"><tt>subsasgn</tt></a></td><td>overloads subsasgn</td></tr><tr><td width="200px"><a href="EBSD.subsind.html"><tt>subsind</tt></a></td><td>subindexing of EBSD data</td></tr><tr><td width="200px"><a href="EBSD.subsref.html"><tt>subsref</tt></a></td><td>indexing of EBSD data</td></tr><tr><td width="200px"><a href="EBSD.updateUnitCell.html"><tt>updateUnitCell</tt></a></td><td>this function should be called after the spatial coordinates of an EBSD</td></tr></table></html>